@@ -1,17 +1,17 @@
-from multiprocessing import AuthenticationError
 from typing import Any, Coroutine
-from rath.links.base import Link, ContinuationLink
+from rath.links.base import AsyncContinuationLink
 from rath.operation import GraphQLResult, Operation
+from rath.links.errors import AuthenticationError
 
 
 async def fake_loader():
-    return "fake_token"
+    raise Exception("No Token loader specified")
 
 
-class AuthTokenLink(ContinuationLink):
+class AuthTokenLink(AsyncContinuationLink):
     def __init__(
         self,
-        token_loader: Coroutine[Any, Any, str],
+        token_loader: Coroutine[Any, Any, str] = fake_loader,
         maximum_refresh_attempts=3,
         load_token_on_connect=True,
     ) -> None:
@@ -22,15 +22,17 @@ class AuthTokenLink(ContinuationLink):
 
     async def reload_token(self) -> None:
         self.token = await self.token_loader()
+        return self.token
 
     async def aquery(self, operation: Operation, retry=0) -> GraphQLResult:
-        if retry >= self.maximum_refresh_attempts:
-            raise AuthenticationError("Maximum refresh attempts reached")
 
-        # operation.context.headers["Authorization"] = f"Bearer {self.token}"
+        operation.context.headers["Authorization"] = f"Bearer {self.token}"
         try:
             return await self.next.aquery(operation)
-        except Exception as e:
+        except AuthenticationError as e:
+            if retry >= self.maximum_refresh_attempts:
+                raise AuthenticationError("Maximum refresh attempts reached") from e
+
             self.token = await self.reload_token()
             return await self.aquery(operation, retry=retry + 1)
 
@@ -48,6 +50,5 @@ class AuthTokenLink(ContinuationLink):
                 yield result
 
     async def aconnect(self) -> None:
-        print("COnnected")
         if self.load_token_on_connect:
             self.token = await self.token_loader()
