@@ -1,6 +1,7 @@
+import asyncio
 from os import link
 from typing import List
-from rath.links.base import Link, TerminatingLink
+from rath.links.base import ContinuationLink, Link, TerminatingLink
 from rath.operation import Operation
 
 
@@ -9,6 +10,10 @@ class ComposedLink(TerminatingLink):
         assert isinstance(
             links[-1], TerminatingLink
         ), "Last link must be a TerminatingLink"
+        for link in links[:-1]:
+            assert isinstance(
+                link, ContinuationLink
+            ), f"All but the last must be ContinuationLinks: check {link}"
         self.links = links
         self.first_link = links[0]
 
@@ -19,8 +24,7 @@ class ComposedLink(TerminatingLink):
         self.links[-1](rath)  # last one gets only rath
 
     async def aconnect(self):
-        for link in self.links:
-            await link.aconnect()
+        return await asyncio.gather(*[link.aconnect() for link in self.links])
 
     async def aquery(self, operation: Operation):
         return await self.first_link.aquery(operation)
@@ -29,6 +33,13 @@ class ComposedLink(TerminatingLink):
         for result in await self.first_link.asubscribe(operation):
             yield result
 
+    def query(self, operation: Operation):
+        return self.first_link.query(operation)
+
+    def subscribe(self, operation: Operation):
+        for result in self.first_link.subscribe(operation):
+            yield result
+
 
 def compose(*links: List[Link]) -> ComposedLink:
     """
